import os
import time

from datetime import datetime

from hash_calc.HashCalc import HashCalc

class Controller():
    def __init__(self, filePath) -> None:
        self.startTime = time.time()
        self.filePath = filePath
        self.hash = HashCalc(self.filePath)

    def printHeader(self):
        print("################################################################################")
        print("")
        print("lineident by 5f0")
        print("Searches files line by line for given words")
        print("")
        print("Current working directory: " + os.getcwd())
        print("")
        print("-->    Path: " + self.filePath)
        print("-->     MD5: " + self.hash.md5)
        print("-->  SHA256: " + self.hash.sha256)
        print("")
        print("Datetime: " + datetime.now().strftime("%d/%m/%Y %H:%M:%S"))
        print("")
        print("################################################################################")
        print("")

    def printOptions(self, words, method):
        print("Search Options:")
        print("---")
        print("")
        print("Method: " + method)
        print(" Words: " + str(words))
        print("")

    def printResults(self, results, format):
        print("")
        print("Result:")
        print("---")
        print("Hits: " + str(len(results)))
        print("---")
        print("")
        if(len(results) > 0):
            for result in results:
                if(format == "std"):
                    print("Line Nr: " + str(result[0]) + " --> " + result[1])
                elif(format=="wln"):
                    print(result[1])
        else:
            print("No lines matched")
        print("")

    def printExecutionTime(self):
        end = time.time()
        print("")
        print("################################################################################")
        print("")
        print("Execution Time: " + str(end-self.startTime)[0:8] + " sec")
        print("")


class Processor():
    def __init__(self, path, method, words) -> None:
        self.path = path
        self.method = method
        self.words = words.split(",")

    def process(self):
        matches = []
        lineCount = 1
        with open(self.path, "r") as f:
            while True:
                next_line = f.readline()

                if not next_line:
                    break

                line = next_line.strip()
                
                if(self.method == "or"):
                    for word in self.words:
                        if(word in line):
                            matches.append((lineCount, line))
                            break
                elif(self.method == "and"):
                    andCount = 0
                    
                    for word in self.words:
                        if(word in line):
                            andCount += 1

                    if(andCount == len(self.words)):        
                        matches.append((lineCount, line))

                lineCount+=1
        return matches


import sys
import argparse

from lineident.Controller import Controller
from lineident.processor.Processor import Processor

def main(args_=None):
    """The main routine."""
    if args_ is None:
        args_ = sys.argv[1:]

    parser = argparse.ArgumentParser()
    parser.add_argument("--path", "-p", type=str, required=True, help="Path to file which shall be searched")
    parser.add_argument("--method", "-m", type=str, choices=["and", "or"], required=True, help="Method to check for words. and/or")
    parser.add_argument("--words", "-w", type=str, required=True, help="CSV input e.g.: dog,cat,hello")
    parser.add_argument("--format", "-f", type=str, choices=["std", "wln"], default="std", help="Output format: std/ol")
    args = parser.parse_args()

    ctrl = Controller(args.path)
    ctrl.printHeader()

    p = Processor(args.path, args.method, args.words)
    results = p.process()

    ctrl.printOptions(p.words, args.method)
    ctrl.printResults(results, args.format)
    ctrl.printExecutionTime()
   

if __name__ == "__main__":
    sys.exit(main())



from setuptools import setup, find_packages

with open("README.md", "r") as r:
    desc = r.read()

setup(
    name="lineident",
    version="1.3.0",
    author="5f0",
    url="https://github.com/5f0ne/lineident",
    description="Searches files line by line for given words",
    classifiers=[
        "Operating System :: OS Independent ",
        "Programming Language :: Python :: 3 ",
        "License :: OSI Approved :: MIT License "
    ],
    license="MIT",
    long_description=desc,
    long_description_content_type="text/markdown",
    package_dir={"": "src"},
    packages=find_packages(where='src'),
    include_package_data=True,
    install_requires=[
        "hash_calc"
    ],
     entry_points={
        "console_scripts": [
            "lineident = lineident.__main__:main"
        ]
    }
)
